function [classProbsTrain,classProbsTest, actual, errWekaBrier,errWekalog,errZEBrier,errZElog ]= genProbsZE(name,classifier)

% please note the function requires the Matlab-R interface available for download at
% http://www.mathworks.co.uk/matlabcentral/fileexchange/5051-matlab-r-link/

% and the Matlab-Weka interface available for download at:
% http://www.mathworks.co.uk/matlabcentral/fileexchange/21204-matlab-weka-interface%

% the experiments were run by using Weka 3.7.10 available for download
% http://www.cs.waikato.ac.nz/ml/weka/

% after download and installation add the paths to Matlab-R and matlab2weka
% (assumes bith within current directory)

addpath(strcat(pwd,'\matlab2weka'));
addpath(strcat(pwd,'\MATLAB-R'));

% open the arff source file (change source directory if different)

wekaOBJ = loadARFF(strcat(pwd,'\data\',name,'.arff'));

% build Weka object

[mdata,featureNames,targetNDX,~,relationName] =weka2matlab(wekaOBJ);

% shuffle the data
    
perm = randperm(size(mdata,1));
mdata = mdata(perm,:);

%rebuild in weka format

cdata=horzcat(num2cell(mdata(:,1:end-1)),cellstr(num2str(mdata(:,end),'%10.5e\n')));

% split into train and test set (2/3 training set)

split=round(0.66*size(cdata,1));

train=cdata(1:split,:);
test=cdata(split+1:end,:);

% wweka format

train = matlab2weka(relationName,featureNames,train,targetNDX);
test = matlab2weka(relationName,featureNames,test);

% train classifier

switch classifier

    case 'tree'
        wekaSwitch='trees.J48';
        wekaExtension=' -C 0.25 -M 2';
        nb = trainWekaClassifier(train,wekaSwitch,{wekaExtension});
    case 'SMO'
      nb=javaObject(['weka.classifiers.','functions.SMO']);
      nb.setOptions(weka.core.Utils.splitOptions('-C 1.0 -L 0.001 -P 1.0E-12 -distribution -M -N 0 -V -1 -W 1 -K "weka.classifiers.functions.supportVector.PolyKernel -C 250007 -E 1.0"'));
      nb.buildClassifier(train);
    case 'naive'
       wekaSwitch='bayes.NaiveBayes';
       wekaExtension='-K';
       nb = trainWekaClassifier(train,wekaSwitch,{wekaExtension});
    case 'logistic'
       wekaSwitch='functions.Logistic';
       wekaExtension='-R 1.0E-8 -M -1';
       nb = trainWekaClassifier(train,wekaSwitch,{wekaExtension});
    case 'bagging'
       wekaSwitch='meta.Bagging';
       wekaExtension=' -P 100 -S 1 -num-slots 1 -I 10 -W weka.classifiers.trees.J48 -- -C 0.25 -M 2';
       nb = trainWekaClassifier(train,wekaSwitch,{wekaExtension});
    case 'nn'
      nb=javaObject(['weka.classifiers.','functions.MultilayerPerceptron']);
      nb.setOptions(weka.core.Utils.splitOptions('-L 0.1 -M 0.1 -N 500 -V 0 -S 0 -E 20 -H a'));
      nb.buildClassifier(train);
end

% obtain train and test classifier probabilities

[~, classProbsTrain] = wekaClassify(train,nb);
[~, classProbsTest] = wekaClassify(test,nb);

%define train vector and prob vector for p0 and p1 (probs)


probsZad=nan(size(mdata,1),2);

% open the connection to R

openR
    
for i=split+1:size(mdata,1)
    


     % build vector for isotonic regression 
     
      reg0=horzcat(vertcat(classProbsTrain(1:split,2),classProbsTest(i-split,2)),vertcat(mdata(1:split,end),0));
      
   [p0,p1,P0,P1]=isoregR(reg0,reg0);
   
   if isempty([p0,p1,P0,P1])==0
   probsZad(i,:)=[P0,P1];
   end

   
end

closeR


% evaluate ZE probabilities

probZad=[probsZad(split+1:end,1),probsZad(split+1:end,2)];

actual=mdata(split+1:end,end);

% evaluate errors

% Weka classifier losses

errWekaBrier=sqrt(sum((actual-classProbsTest(:,2)).^2)/size(actual,1));
errWekalog=zeros(size(actual,1),1);
errWekalog(actual==1)=-log(classProbsTest(actual==1,2));
errWekalog(actual==0)=-log(classProbsTest(actual==0,1));
errWekalog=sum(errWekalog)/size(actual,1);

% ZE losses

errZEBrier=sqrt(sum((actual-probZad(:,2)).^2)/size(actual,1));
errZElog=zeros(size(actual,1),1);
errZElog(actual==1)=-log(probZad(actual==1,2));
errZElog(actual==0)=-log(probZad(actual==0,1));
errZElog=sum(errZElog)/size(actual,1);

end

